
def test_setup_docker_xnat():
    import os
    import pyxnat

    x = pyxnat.Interface(config='.xnat.cfg')

    cmd = 'curl --cookie-jar /tmp/cookie --header "Content-Type: application/x-www-form-urlencoded" '\
        '--request POST '\
        '--data "username={user}&password={password}&login=&XNAT_CSRF=" '\
        'http://localhost/login'.format(user=x._user, password=x._pwd)
    print(cmd)
    os.system(cmd)

    cmd = 'curl --cookie /tmp/cookie --header "Content-Type: application/json" '\
        '--request POST '\
        '--data \'%s\' '\
        'http://localhost/xapi/siteConfig'

    cmd2 = cmd % '{"siteId": "XNAT", "siteUrl": "http://localhost", "adminEmail": "fake@fake.fake"}'
    print(cmd2)
    os.system(cmd2)

    cmd2 = cmd % '{"archivePath":"/data/xnat/archive","prearchivePath":"/data/xnat/prearchive","cachePath":"/data/xnat/cache","buildPath":"/data/xnat/build","ftpPath":"/data/xnat/ftp","pipelinePath":"/data/xnat/pipeline","inboxPath":"/data/xnat/inbox"}'
    print(cmd2)
    os.system(cmd2)

    cmd2 = cmd % '{"requireLogin":true,"userRegistration":false,"enableCsrfToken":true}'
    print(cmd2)
    os.system(cmd2)

    cmd2 = cmd % '{"initialized":true}'
    print(cmd2)
    os.system(cmd2)


    p = x.select.project('nosetests')
    p.create()
    for i in range(3, 10):
        p = x.select.project('nosetests%s' % i)
        p.create()

    uri = '/data/projects/nosetests'
    options = {'alias': 'nosetests2'}
    data = x.put(uri, params=options).text



import os.path as op
from subprocess import Popen
import multiprocessing as mp

import pyxnat

URL = 'https://central.xnat.org'  # central URL
BET = 'fsl4.1-bet2'               # BET executable path

central = pyxnat.Interface(URL, anonymous=True)  # connection object


def bet(in_img, in_hdr):  # Python wrapper on FSL BET, essentially a system call
    in_image = in_img.get()     # download .img
    in_hdr.get()                # download .hdr
    path, name = op.split(in_image)
    in_image = op.join(path, name.rsplit('.')[0])
    out_image = op.join(path, name.rsplit('.')[0] + '_brain')
    print('==> %s' % in_image[-120:])
    Popen('%s %s %s' % (BET, in_image, out_image),
          shell=True).communicate()
    return out_image


def notify(message):  # message to notify the end of a BET process
    print('<== %s' % message[-120:])


pool = mp.Pool(processes=mp.cpu_count() * 2)  # pool of concurrent workers
images = {}
query = ('/projects/CENTRAL_OASIS_CS/subjects/*'
         '/experiments/*_MR1/scans/mpr-1*/resources/*/files/*')
filter_ = [('xnat:mrSessionData/AGE', '>', '80'), 'AND']

for f in central.select(query).where(filter_):
    label = f.label()
    # images are stored in pairs of files (.img, .hdr) in this project
    if label.endswith('.img'):
        images.setdefault(label.split('.')[0], []).append(f)
    if f.label().endswith('.hdr'):
        images.setdefault(label.split('.')[0], []).append(f)
    # download and process both occur in parallel within the workers
    for name in images.keys():
        if len(images[name]) == 2:  # if .img and .hdr XNAT refs are ready
            img, hdr = images.pop(name)                        # get references
            pool.apply_async(bet, (img, hdr), callback=notify)  # start worker
pool.close()
pool.join()



import os
from subprocess import Popen
from multiprocessing import Pool

import pyxnat

url = 'https://imagen.cea.fr/imagen_database'

login = ''
password = ''
interface = pyxnat.Interface(url, login, password)


def bet(in_image):
    path, name = os.path.split(in_image)
    in_image = os.path.join(path, name.rsplit('.')[0])
    out_image = os.path.join(path, name.rsplit('.')[0] + '_brain')

    print('==> %s' % in_image[-120:])

    Popen('bet2 %s %s -f 0.5 -g 0 ' % (in_image, out_image),
          shell=True).communicate()

    return out_image


def notify(message):
    print('<== %s' % message[-120:])


pool = Pool(processes=8)
uri = '//experiments/*SessionA*/assessors/*ADNI*/out/resources/files'
iu = interface.select(uri)

for mprage in iu.where([('psytool:tci_parentData/TCI051', '=', '1'), 'AND']):
    pool.apply_async(bet, (mprage.get(),), callback=notify)

pool.close()
pool.join()



import os.path as op
from pyxnat import Interface
from . import skip_if_no_network

_modulepath = op.dirname(op.abspath(__file__))

fp = op.join(op.dirname(op.abspath(__file__)), 'central.cfg')
central = Interface(config=fp)


@skip_if_no_network
def test_global_experiment_listing():
    assert central.array.experiments(project_id='CENTRAL_OASIS_CS',
                                     experiment_type='xnat:mrSessionData',
                                     )



# -*- coding: utf-8 -*-
#
# pyxnat documentation build configuration file, created by
# sphinx-quickstart on Tue Nov 24 11:04:02 2009.
#
# This file is execfile()d with the current directory set to its parent dir.
#
# The contents of this file are pickled, so don't put values in the namespace
# that aren't pickleable
# (module imports are okay, they're removed automatically).
#
# Note that not all possible configuration values are present in this
# autogenerated file.
#
# All configuration values have a default; values that are commented out
# serve to show the default.

import sys
import os
import sphinx_theme


def get_version():
    try:
        import re
        import os.path as op
        fp = op.join(op.split(op.dirname(__file__))[0], 'pyxnat', 'version.py')
        s = re.search(r'{}\s*=\s*[\'"]([^\'"]*)[\'"]'.format('VERSION'),
                      open(fp).read())
        return s.group(1)
    except Exception:
        raise RuntimeError("No version found")


sys.path.append(os.path.abspath('..'))

# If your extensions (or modules documented by autodoc) are in another
# directory, add these directories to sys.path here. If the directory is
# relative to the documentation root, use os.path.abspath to make it absolute,
# like shown here.
# sys.path.append(os.path.abspath('.'))

# General configuration
# ---------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
extensions = ['sphinx.ext.autodoc',
              'sphinx.ext.napoleon',
              'sphinx.ext.autosummary']

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The suffix of source filenames.
source_suffix = '.rst'

# The encoding of source files.
# source_encoding = 'utf-8'

# The master toctree document.
master_doc = 'index'

# General information about the project.
project = 'pyxnat'
copyright = '2010, Yannick Schwartz'

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#
# The short X.Y version.
version = get_version()[:3]
# The full version, including alpha/beta/rc tags.
release = get_version()

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
# language = None

# There are two options for replacing |today|: either, you set today to some
# non-false value, then it is used:
# today = ''
# Else, today_fmt is used as the format for a strftime call.
# today_fmt = '%B %d, %Y'

# List of documents that shouldn't be included in the build.
# unused_docs = []

# List of directories, relative to source directory, that shouldn't be searched
# for source files.
exclude_trees = ['_build']

# The reST default role (used for this markup: `text`) to use for all documents
# default_role = None

# If true, '()' will be appended to :func: etc. cross-reference text.
# add_function_parentheses = True

# If true, the current module name will be prepended to all description
# unit titles (such as .. function::).
# add_module_names = True

# If true, sectionauthor and moduleauthor directives will be shown in the
# output. They are ignored by default.
# show_authors = False

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'


# Options for HTML output
# -----------------------

# The style sheet to use for HTML and HTML Help pages. A file of that name
# must exist either in Sphinx' static/ path, or in one of the custom paths
# given in html_static_path.
# html_style = 'default.css'

# The theme to use for HTML and HTML Help pages.  Major themes that come with
# Sphinx are currently 'default' and 'sphinxdoc'.
html_theme = 'stanford_theme'
html_theme_path = [sphinx_theme.get_html_theme_path('stanford-theme')]

# The name for this set of Sphinx documents.  If None, it defaults to
# "<project> v<release> documentation".
# html_title = None

# A shorter title for the navigation bar.  Default is the same as html_title.
# html_short_title = None

# The name of an image file (relative to this directory) to place at the top
# of the sidebar.
# html_logo = None

# The name of an image file (within the static path) to use as favicon of the
# docs.  This file should be a Windows icon file (.ico) being 16x16 or 32x32
# pixels large.
html_favicon = "pyxnat.ico"

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
# html_static_path = ['_static']

# If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
# using the given strftime format.
# html_last_updated_fmt = '%b %d, %Y'

# If true, SmartyPants will be used to convert quotes and dashes to
# typographically correct entities.
# html_use_smartypants = True

# Custom sidebar templates, maps document names to template names.
# html_sidebars = {}

# Additional templates that should be rendered to pages, maps page names to
# template names.
# html_additional_pages = {}

# If false, no module index is generated.
# html_use_modindex = True

# If false, no index is generated.
# html_use_index = True

# If true, the index is split into individual pages for each letter.
# html_split_index = False

# If true, the reST sources are included in the HTML build as _sources/<name>.
# html_copy_source = True

# If true, an OpenSearch description file will be output, and all pages will
# contain a <link> tag referring to it.  The value of this option must be the
# base URL from which the finished HTML is served.
# html_use_opensearch = ''

# If nonempty, this is the file name suffix for HTML files (e.g. ".xhtml").
# html_file_suffix = ''

# Output file base name for HTML help builder.
htmlhelp_basename = 'pyxnatdoc'


# Options for LaTeX output
# ------------------------

# The paper size ('letter' or 'a4').
# latex_paper_size = 'letter'

# The font size ('10pt', '11pt' or '12pt').
# latex_font_size = '10pt'

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title, author, document class
# [howto/manual])
latex_documents = [
  ('index', 'pyxnat.tex', r'pyxnat Documentation',
   r'Yannick Schwartz', 'manual'),
]

# The name of an image file (relative to this directory) to place at the top of
# the title page.
# latex_logo = None

# For "manual" documents, if this is true, then toplevel headings are parts,
# not chapters.
# latex_use_parts = False

# Additional stuff for the LaTeX preamble.
# latex_preamble = ''

# Documents to append as an appendix to all manuals.
# latex_appendices = []

# If false, no module index is generated.
# latex_use_modindex = True


# Example configuration for intersphinx: refer to the Python standard library.
intersphinx_mapping = {'http://docs.python.org/dev': None}
